@@ -1,7 +1,7 @@
 import time
 
 from fabric.api import env, run, sudo
-from fabric.context_managers import settings as fabric_settings
+from fabric.context_managers import cd, settings as fabric_settings
 from fabric.contrib.files import append, sed, uncomment
 from fabric.operations import reboot
 
@@ -42,7 +42,7 @@ def bootstrap():
     run("rc.d start haveged", pty=False)
 
     # upgrade everything except glibc
-    run("printf 'n\nY\nY\nY\nY\nY\nY\nY\nY\nY\nY\n' | pacman -Su --ignore glibc")
+    run("printf 'n\nY\nY\nY\nY\nY\nY\nY\nY\nY\nY\nY\nY\nY\n' | pacman -Su --ignore glibc")
 
     # configure pacman
     run("pacman-key --init")
@@ -73,7 +73,8 @@ def bootstrap():
     # more glibc crap, uninstall non-pacman rackspace installed packages
     run("rm -rf /lib/modules")
     run("pacman --noconfirm -Rns xe-guest-utilities kernel26-xen")
-    sudo("yaourt --noconfirm -S xe-guest-utilities", user="aur")
+    with cd("/tmp/"):
+        sudo("yaourt --noconfirm -S xe-guest-utilities", user="aur")
 
     # finally we can upgrade glibc and run a successful full system upgrade
     run("pacman --noconfirm -Su")
@@ -89,7 +90,7 @@ def bootstrap():
 
     # upgrade grub
     run("mv /boot/grub /boot/grub-legacy")
-    run("printf 'y\nY\nY\nY\nY\n' | pacman -S grub2-bios")
+    run("printf 'y\nY\nY\nY\nY\nY\nY\nY\nY\nY\n' | pacman -S grub-bios")
     with fabric_settings(warn_only=True):
         run("modprobe dm_mod")
     run("grub-install --directory=/usr/lib/grub/i386-pc --target=i386-pc --boot-directory=/boot --recheck --debug /dev/xvda")
@@ -106,12 +107,13 @@ def install_salt(installer="aur"):
     """
     Install salt with the chosen installer.
     """
-    if installer == "aur":
-        sudo("yaourt --noconfirm -S salt", user="aur")
-    elif installer == "aur-git":
-        sudo("yaourt --noconfirm -S salt-git", user="aur")
-    else:
-        raise NotImplementedError()
+    with cd("/tmp/"):
+        if installer == "aur":
+            sudo("yaourt --noconfirm -S salt", user="aur")
+        elif installer == "aur-git":
+            sudo("yaourt --noconfirm -S salt-git", user="aur")
+        else:
+            raise NotImplementedError()
 
 
 def setup_salt():
@@ -138,11 +140,12 @@ def start_salt():
     """
     Starts salt master and minions.
     """
-    if env.host == env.master_server.public_ip:
-        sudo("rc.d start salt-master", pty=False)
-        time.sleep(3)
-        sudo("rc.d start salt-minion", pty=False)
-    else:
+    # use warn_only to catch already running errors
+    # probably should use pgrep instead
+    with fabric_settings(warn_only=True):
+        if env.host == env.master_server.public_ip:
+            sudo("rc.d start salt-master", pty=False)
+            time.sleep(3)
         sudo("rc.d start salt-minion", pty=False)
 
 
@@ -150,10 +153,10 @@ def restart_salt():
     """
     Restarts salt master and minions.
     """
+    # use warn_only to catch already running errors
+    # probably should use pgrep instead
     with fabric_settings(warn_only=True):
         if env.host == env.master_server.public_ip:
             sudo("rc.d restart salt-master", pty=False)
             time.sleep(3)
-            sudo("rc.d restart salt-minion", pty=False)
-        else:
-            sudo("rc.d restart salt-minion", pty=False)
+        sudo("rc.d restart salt-minion", pty=False)
